==> dart_code_metrics-4.4.0.tar.gz: lib/src/analyzers/lint_analyzer/metrics/metric_utils.dart <==
import 'models/metric_value_level.dart';

/// Returns the url of a page containing documentation associated with [metricId]
Uri documentation(String metricId) => Uri(
      scheme: 'https',
      host: 'dartcodemetrics.dev',
      pathSegments: [
        'docs',
        'metrics',
        metricId,
      ],
    );

/// Returns a nullable threshold from [config] for metric with [metricId]
T? readNullableThreshold<T extends num>(
  Map<String, Object?> config,
  String metricId,
) {
  final configValue = config[metricId]?.toString();

  if (configValue != null && T == int) {
    return int.tryParse(configValue) as T?;
  } else if (configValue != null && T == double) {
    return double.tryParse(configValue) as T?;
  }

  return null;
}

/// Returns calculated [MetricValueLevel] based on the [value] to [warningLevel] ratio
MetricValueLevel valueLevel(num? value, num? warningLevel) {
  if (value == null || warningLevel == null) {
    return MetricValueLevel.none;
  }

  if (value > warningLevel * 2) {
    return MetricValueLevel.alarm;
  } else if (value > warningLevel) {
    return MetricValueLevel.warning;
  } else if (value > warningLevel * 0.8) {
    return MetricValueLevel.noted;
  }

  return MetricValueLevel.none;
}

/// Returns calculated [MetricValueLevel] based on the [value] to [warningLevel] inverted ratio
MetricValueLevel invertValueLevel(num? value, num? warningLevel) {
  if (value == null || warningLevel == null) {
    return MetricValueLevel.none;
  }

  if (value < warningLevel * 0.5) {
    return MetricValueLevel.alarm;
  } else if (value < warningLevel) {
    return MetricValueLevel.warning;
  } else if (value < warningLevel * 1.25) {
    return MetricValueLevel.noted;
  }

  return MetricValueLevel.none;
}

/// Determines if the [level] warns about need to be a report about a metric value
bool isReportLevel(MetricValueLevel level) =>
    level == MetricValueLevel.warning || level == MetricValueLevel.alarm;

/// Returns user friendly string representations of [type].
String userFriendlyType(Type type) {
  const _impl = 'Impl';

  final typeName = type.toString();

  return typeName.endsWith(_impl)
      ? typeName.substring(0, typeName.length - _impl.length)
      : typeName;
}

==> dart_code_metrics-4.6.0.tar.gz: lib/src/analyzers/lint_analyzer/metrics/metric_utils.dart <==
import 'models/metric_value_level.dart';

/// Returns the url of a page containing documentation associated with [metricId]
Uri documentation(String metricId) => Uri(
      scheme: 'https',
      host: 'dartcodemetrics.dev',
      pathSegments: [
        'docs',
        'metrics',
        metricId,
      ],
    );

/// Returns a nullable threshold from [config] for metric with [metricId]
T? readNullableThreshold<T extends num>(
  Map<String, Object?> config,
  String metricId,
) {
  final metricConfig = config[metricId];

  final configValue = metricConfig is Map<String, Object?>
      ? metricConfig['threshold']?.toString()
      : metricConfig?.toString();

  if (configValue != null && T == int) {
    return int.tryParse(configValue) as T?;
  } else if (configValue != null && T == double) {
    return double.tryParse(configValue) as T?;
  }

  return null;
}

/// Returns calculated [MetricValueLevel] based on the [value] to [warningLevel] ratio
MetricValueLevel valueLevel(num? value, num? warningLevel) {
  if (value == null || warningLevel == null) {
    return MetricValueLevel.none;
  }

  if (value > warningLevel * 2) {
    return MetricValueLevel.alarm;
  } else if (value > warningLevel) {
    return MetricValueLevel.warning;
  } else if (value > warningLevel * 0.8) {
    return MetricValueLevel.noted;
  }

  return MetricValueLevel.none;
}

/// Returns calculated [MetricValueLevel] based on the [value] to [warningLevel] inverted ratio
MetricValueLevel invertValueLevel(num? value, num? warningLevel) {
  if (value == null || warningLevel == null) {
    return MetricValueLevel.none;
  }

  if (value < warningLevel * 0.5) {
    return MetricValueLevel.alarm;
  } else if (value < warningLevel) {
    return MetricValueLevel.warning;
  } else if (value < warningLevel * 1.25) {
    return MetricValueLevel.noted;
  }

  return MetricValueLevel.none;
}

/// Determines if the [level] warns about need to be a report about a metric value
bool isReportLevel(MetricValueLevel level) =>
    level == MetricValueLevel.warning || level == MetricValueLevel.alarm;

/// Returns user friendly string representations of [type].
String userFriendlyType(Type type) {
  const _impl = 'Impl';

  final typeName = type.toString();

  return typeName.endsWith(_impl)
      ? typeName.substring(0, typeName.length - _impl.length)
      : typeName;
}
